@@ -1,10 +1,10 @@
 library(lingtypology)
 
-df <- data.frame(my_langs = c("Baltic"), stringsAsFactors = FALSE)
+df <- data.frame(my_langs = c("Eastern Baltic"), stringsAsFactors = FALSE)
 
 test_that("lang.aff", {
   skip_on_cran()
-    expect_equal(lang.aff("Baltic"), c("Lithuanian", "Latvian"))
+    expect_equal(lang.aff("Eastern Baltic"), c("Lithuanian", "Latvian"))
     expect_equal(lang.aff(df), c(my_langs1 = "Lithuanian",
                                  my_langs2 = "Latvian"))
     expect_equal(lang.aff(c("Brythonic", "Goidelic")), c("Old South-West British",
